@@ -1,10 +1,10 @@
 import os
-import logging
 from aiohttp import web
 from sqlalchemy import (
     MetaData, Table, Column,
     String, JSON, create_engine
 )
+from .log import logger
 
 __all__ = ['configuration']
 
@@ -21,7 +21,7 @@ configuration = Table(
 )
 
 
-async def configs(request):
+async def _configs(request):
     configurations = []
     try:
         async with request.app['db'].acquire() as conn:
@@ -35,7 +35,12 @@ async def configs(request):
                 meta.create_all(create_engine(os.environ['DATABASE_URL']))
                 raise
     except Exception:
-        logging.exception('EMPTY CONFIGS %r', request.app)
+        logger.exception('EMPTY CONFIGS %r', request.app)
+    return configurations
+
+
+async def configs(request):
+    configurations = await _configs(request)
     res = {
         'configurations': configurations
     }
@@ -49,16 +54,15 @@ class ConfigHeaderMappings():
 
     async def header_mapping(self, taxonomy_id, request):
         if not self._header_mappings.get(taxonomy_id):
-            await self.refresh(request)
+            try:
+                await self.refresh(request)
+            except Exception:
+                logger.exception('Failed to read header mappings from configuration, skipping')
         return self._header_mappings.get(taxonomy_id, {})
 
     async def refresh(self, request):
         async with request.app['db'].acquire() as conn:
-            configurations = await conn.execute(
-                configuration.select()
-            )
-            configurations = await configurations.fetchall()
-            configurations = [dict(x) for x in configurations]
+            configurations = await _configs(request)
             for config in configurations:
                 config = config.get('config', {})
                 taxonomy_id = config.get('taxonomy', {}).get('id')
